| WSS | R Documentation |
Caluclates the WSS genetic score
WSS(x, genomic.region = x@snps$genomic.region)
x |
A bed.matrix |
genomic.region |
A factor containing the genomic region of each variant |
A matrix containing the WSS genetic score with one row per individual and one column per genomic.region
Madsen E and Browning S. A Groupwise Association Test for Rare Mutations Using a Weighted Sum Statistic. PLoS Genet. 2009
CAST, burden.weighted.matrix, burden.mlogit
#Import data in a bed matrix
x <- read.bed.matrix( system.file("extdata", "LCT.EUR.b37.bed", package="Ravages") )
#Group variants within known genes
x <- set.genomic.region(x)
#Filter of rare variants: only non-monomorphic variants with
#a MAF lower than 2.5%
#keeping only genomic regions with at least 10 SNP
x1 <- filter.rare.variants(x, filter = "whole", maf.threshold = 0.025, min.nb.snps = 10)
# Compute burden score WSS
score.WSS <- WSS(x1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.