Learn R Programming

Ravages (version 1.2.0)

adjustedCADD.annotation: SNVs and Indels annotation with adjusted CADD scores

Description

Annotate SNVs and Indels with the adjusted CADD scores (CADD PHRED scores for coding, regulatory and intergenic regions)

Usage

adjustedCADD.annotation(x, SNVs.scores = NULL, indels.scores = NULL,
			cores = 10, verbose = T, path.data, 
                        build = c("b37", "b38"))

Value

The bed matrix x with adjusted CADD scores in adjCADD.

Arguments

x

A bed.matrix annotated with CADD regions using set.CADDregions

SNVs.scores

A dataframe with the columns 'chr', 'pos', 'A1', 'A2' and 'adjCADD' containing the ADJUSTED CADD scores of the SNVs (Optional, useful to gain in computation time if the adjusted CADD scores of variants in the study are available)

indels.scores

A dataframe with the columns 'chr', 'pos', 'A1', 'A2' and 'PHRED_1.4' (or 'PHRED_1.6' if build 38) containing the CADD PHREDv1.4 (of PHREDv1.6) scores of the indels - Compulsory if indels are present in x

cores

How many cores to use, set at 10 by default

verbose

Whether to display information about the function actions

path.data

The repository where data for RAVA-FIRST are or will be downloaded from https://lysine.univ-brest.fr/RAVA-FIRST/

build

The build of the data, either "b37" or "b38". The CADD Regions in the corresponding build will be considered

Details

bedtools need to be installed on the system to run this function if indels are present are if scores are not provided for SNVs.

This function calls adjustedCADD.annotation.SNVs and adjustedCADD.annotation.indels. See the help of those two functions for more details.

See Also

adjustedCADD.annotation.SNVs, adjustedCADD.annotation.indels, RAVA.FIRST, filter.adjustedCADD

Examples

Run this code
####Build37
#Import 1000Genome data from region around LCT gene
#x37 <- read.bed.matrix( system.file("extdata", "LCT.EUR.b37.bed", package="Ravages") )

#Annotate variants with adjusted CADD score
#x37 <- adjustedCADD.annotation(x37, build = "b37")

####Build38
#Import 1000Genome data from region around LCT gene
#x38 <- read.bed.matrix( system.file("extdata", "LCT.EUR.b38.bed", package="Ravages") )

#Annotate variants with adjusted CADD score
#x38 <- adjustedCADD.annotation(x38, build = "b38")

Run the code above in your browser using DataLab