View source: R/burden_mlogit_subscores.r
| burden.mlogit.subscores | R Documentation |
Performs burden tests with subscores in the regression on categorical phenotypes
burden.mlogit.subscores(x, NullObject, genomic.region = x@snps$genomic.region,
SubRegion = x@snps$SubRegion, burden.function = WSS,
maf.threshold = 0.5, get.effect.size = FALSE,
alpha = 0.05, cores = 10)
x |
A bed matrix, only needed if |
NullObject |
A list returned from |
genomic.region |
A factor containing the genomic region of each SNP, |
SubRegion |
A vector containing subregions within each |
burden.function |
A function to compute the genetic score, |
maf.threshold |
The MAF threshold to use for the definition of a rare variant in the CAST score. Set at 0.5 by default |
get.effect.size |
TRUE/FALSE: whether to return effect sizes of the tested |
alpha |
The alpha threshold to use for the OR confidence interval |
cores |
How many cores to use, set at 10 by default. Only needed if |
This function will return results from the regression of the phenotype on the genetic score(s) for each genomic region. Within each genomic region, a subscore will be computed for each SubRegion and one test will be performed for each genomic.region.
If only two groups of individuals are present, a classical logistic regression is performed.
If more than two groups of individuals are present, a non-ordinal multinomial regression is performed,
comparing each group of individuals to the reference group indicated by the argument ref.level in NullObject.parameters.
The choice of the reference group won't affect the p-values, but only the Odds Ratios.
In both types of regression, the p-value is estimated using the Likelihood Ratio test and the function burden.mlogit.
A dataframe with one row per genomic region and two columns:
p.value |
The p.value of the regression |
is.err |
0/1: whether there was a convergence problem with the regression |
If get.effect.size=TRUE, a list is returned with the previous dataframe in $Asso and with effect, a list containing matrices with three columns:
OR |
The OR value(s) associated to the subscores in the regression. If there are more than two groups, there will be one OR value per group compared to the reference group |
l.lower |
The lower bound of the confidence interval of each OR |
l.upper |
The upper bound of the confidence interval of each OR |
NullObject.parameters, burden.subscores, CAST, WSS
#Import data in a bed matrix
#x <- read.bed.matrix( system.file("extdata", "LCT.EUR.b37.bed", package="Ravages") )
#Group variants within CADD regions and genomic categories
#x <- set.CADDregions(x, build = "b37")
#Filter of rare variants: only non-monomorphic variants with
#a MAF lower than 2.5%
#keeping only genomic regions with at least 200 SNP
#x1 <- filter.rare.variants(x, filter = "whole", maf.threshold = 0.025, min.nb.snps = 200)
#run null model, using the 1000Genome population as "outcome"
#x1.H0 <- NullObject.parameters(pheno = x1@ped$population, ref.level = "CEU",
# RVAT = "burden", pheno.type = "categorical")
#run burden test WSS
#res.subscores <- burden.subscores(x1, NullObject = x1.H0, burden = WSS,
# get.effect.size=TRUE, cores = 1)
#res.subscores$Asso # p-values
#res.subscores$effect #OR values
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.