| LCT.EUR | R Documentation |
These data contain the genotype matrix from the 1000 Genomes EUR ancestry individuals in the Lactase gene (positions retrieved from GeneCards.
Information about individuals is present in LCT.EUR.b37/b38.fam, including the subpopulation, in a format needed to generate a bedmatrix.
Two set of files are available: one set in build 37, and one set in build 38.
Data have been anonymized by randomly sampling the genotype positions.
LCT.EUR.b37/b38.bedBinary genotype file
LCT.EUR.b37/b38.bimVariant information file
LCT.EUR.b37/b38.famSample information file
Data were obtained from the 1000 Genomes Project.
McVean et al, 2012, An integrated map of genetic variation from 1,092 human genomes, Nature 491, 56-65 doi:10.1038/nature11632
#Import data in a bed matrix
x <- read.bed.matrix( system.file("extdata", "LCT.EUR.b37.bed", package="Ravages") )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.