Learn R Programming

Ravages (version 1.2.0)

LCT.EUR: LCT genotypes matrix

Description

These data contain the genotype matrix from the 1000 Genomes EUR ancestry individuals in the Lactase gene (positions retrieved from GeneCards. Information about individuals is present in LCT.EUR.b37/b38.fam, including the subpopulation, in a format needed to generate a bedmatrix. Two set of files are available: one set in build 37, and one set in build 38. Data have been anonymized by randomly sampling the genotype positions.

Arguments

Format

LCT.EUR.b37/b38.bed

Binary genotype file

LCT.EUR.b37/b38.bim

Variant information file

LCT.EUR.b37/b38.fam

Sample information file

References

McVean et al, 2012, An integrated map of genetic variation from 1,092 human genomes, Nature 491, 56-65 doi:10.1038/nature11632

Examples

Run this code
#Import data in a bed matrix
x <- read.bed.matrix( system.file("extdata", "LCT.EUR.b37.bed", package="Ravages") )

Run the code above in your browser using DataLab